==> piwigo-2.7.4.zip: piwigo/language/ca_ES/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = "Instal·lació";
$lang['Basic configuration'] = "Configuració bàsica";
$lang['Default gallery language'] = "Idioma predeterminat de la galeria";
$lang['Database configuration'] = "Configuració de la base de dades";
$lang['Admin configuration'] = "Configuració de l'administrador";
$lang['Start Install'] = "Inicia la instal·lació";
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Això es mostrarà als visitants. És necessari pel web d\'administració';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'La connexió amb el servidor s\'ha establert correctament però no és possible connectar amb la base de dades.';
$lang['Can\'t connect to server'] = "No es pot connectar amb el servidor";
$lang['Host'] = 'Allotjament';
$lang['User'] = "Usuari";
$lang['user login given by your host provider'] = 'nom d\'usuari facilitat pel teu proveïdor d\'allotjament';
$lang['user password given by your host provider'] = 'clau d\'accès de l\'usuari facilitada pel teu proveïdor d\'allotjament';
$lang['Database name'] = "Nom de la base de dades";
$lang['also given by your host provider'] = 'també el dóna el teu proveïdor d\'allotjament';
$lang['Database table prefix'] = "Prefix de les taules de la base de dades";
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = "Els noms de les taules de la base de dades començaran amb aquest prefix (permet gestionar millor les taules)";
$lang['enter a login for webmaster'] = "Introdueix un nom d'usuari per l'administrador de la web";
$lang['webmaster login can\'t contain characters \' or "'] = "El nom d'usuari de l'administrador de la web no pot contenir caràcters \' o \"";
$lang['please enter your password again'] = "si us plau introduïu una altra vegada la vostra contrasenya";
$lang['Keep it confidential, it enables you to access administration panel'] = 'Manté la confidencialitat, permet accedir al panell d\'administració';
$lang['Password [confirm]'] = "Contrasenya [confirmeu]";
$lang['verification'] = "verificació";
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = "Necessiteu ajuda? Feu la vostra pregunta a <a href=\"%s\">Piwigo message board</a>.";
$lang['Visitors will be able to contact site administrator with this mail'] = "Els visitants poden utilitzar aquesta adreça de correu electrònic per a contactar amb l'administrador del lloc";
$lang['PHP 5 is required'] = "Es requereix PHP 5 ";
$lang['It appears your webhost is currently running PHP %s.'] = "Sembla que el vostre amfitrió web està executant la versió PHP %s.";
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo pot tractar de canviar la teva configuració per PHP 5 mitjançant la creació o modificació de l\'arxiu .htaccess';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Tingues en compte que en qualsevol moment pots canviar la configuració i reiniciar Piwigo.';
$lang['Try to configure PHP 5'] = "Intenteu configurar PHP 5";
$lang['Sorry!'] = "Perdó!";
$lang['Piwigo was not able to configure PHP 5.'] = "A Piwigo no li ha estat possible configurar PHP 5.";
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = "Haurieu d'adreçar-vos al vostre proveidor d'hostatge i averiguar com poder canviar-vos cap a PHP 5.";
$lang['Hope to see you back soon.'] = "Esperem tornar-vos a veure ben aviat.";
$lang['Congratulations, Piwigo installation is completed'] = 'Felicitats, la instal·lació de Piwigo s\'ha completat';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Una solució alternativa és copiar el text del quadre del costat i pegar-lo dins del fitxer "local/config/database.inc.php" (Advertiment : el fitxer database.inc.php només ha de contenir el que hi ha a l\'àrea de text, sense linia de retorn o caràcter d\'espai)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'La creació del fitxer de configuració local/config/database.inc.php ha fallat.';
$lang['Download the config file'] = 'Descarregat l\'arxiu de configuració';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Pots descarregar l\'arxiu de configuració i penjar-lo al directori local/config de la teva instal·lació.';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'No dubtis en consultar als nostres fòrums per a qualsevol ajuda: %s';
$lang['Just another Piwigo gallery'] = 'Just another Piwigo gallery';
$lang['Welcome to my photo gallery'] = 'Benvingut a la meva galeria fotogràfica';
$lang['Welcome to your new installation of Piwigo!'] = 'Benvingut a la teva nova instal·lació de Piwigo!';
$lang['localhost or other, supplied by your host provider'] = 'localhost o un altre, facilitat pel teu proveïdor d\'allotjament';
?>

==> piwigo-11.5.0.zip: piwigo/language/ca_ES/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = "Instal·lació";
$lang['Basic configuration'] = "Configuració bàsica";
$lang['Default gallery language'] = "Idioma predeterminat de la galeria";
$lang['Database configuration'] = "Configuració de la base de dades";
$lang['Admin configuration'] = "Configuració de l'administrador";
$lang['Start Install'] = "Inicia la instal·lació";
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Això es mostrarà als visitants. És necessari pel web d\'administració';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'La connexió amb el servidor s\'ha establert correctament però no és possible connectar amb la base de dades.';
$lang['Can\'t connect to server'] = "No es pot connectar amb el servidor";
$lang['Host'] = 'Allotjament';
$lang['User'] = "Usuari";
$lang['user login given by your host provider'] = 'nom d\'usuari facilitat pel teu proveïdor d\'allotjament';
$lang['user password given by your host provider'] = 'clau d\'accès de l\'usuari facilitada pel teu proveïdor d\'allotjament';
$lang['Database name'] = "Nom de la base de dades";
$lang['also given by your host provider'] = 'també el dóna el teu proveïdor d\'allotjament';
$lang['Database table prefix'] = "Prefix de les taules de la base de dades";
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = "Els noms de les taules de la base de dades començaran amb aquest prefix (permet gestionar millor les taules)";
$lang['enter a login for webmaster'] = "Introdueix un nom d'usuari per l'administrador de la web";
$lang['webmaster login can\'t contain characters \' or "'] = "El nom d'usuari de l'administrador de la web no pot contenir caràcters \' o \"";
$lang['please enter your password again'] = "si us plau introduïu una altra vegada la vostra contrasenya";
$lang['Keep it confidential, it enables you to access administration panel'] = 'Manté la confidencialitat, permet accedir al panell d\'administració';
$lang['Password [confirm]'] = "Contrasenya [confirmeu]";
$lang['verification'] = "verificació";
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = "Necessiteu ajuda? Feu la vostra pregunta a <a href=\"%s\">Piwigo message board</a>.";
$lang['Visitors will be able to contact site administrator with this mail'] = "Els visitants poden utilitzar aquesta adreça de correu electrònic per a contactar amb l'administrador del lloc";
$lang['PHP 5 is required'] = 'Es requereix PHP 5.2';
$lang['It appears your webhost is currently running PHP %s.'] = "Sembla que el vostre amfitrió web està executant la versió PHP %s.";
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo pot tractar de canviar la teva configuració per PHP 5.2 mitjançant la creació o modificació de l\'arxiu .htaccess';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Tingues en compte que en qualsevol moment pots canviar la configuració i reiniciar Piwigo.';
$lang['Try to configure PHP 5'] = 'Intenteu configurar PHP 5.2';
$lang['Sorry!'] = "Perdó!";
$lang['Piwigo was not able to configure PHP 5.'] = 'A Piwigo no li ha estat possible configurar PHP 5.2';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Haurieu d\'adreçar-vos al vostre proveidor d\'hostatge i averiguar com poder canviar-vos cap a PHP 5.2';
$lang['Hope to see you back soon.'] = "Esperem tornar-vos a veure ben aviat.";
$lang['Congratulations, Piwigo installation is completed'] = 'Felicitats, la instal·lació de Piwigo s\'ha completat';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Una solució alternativa és copiar el text del quadre del costat i pegar-lo dins del fitxer "local/config/database.inc.php" (Advertiment : el fitxer database.inc.php només ha de contenir el que hi ha a l\'àrea de text, sense linia de retorn o caràcter d\'espai)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'La creació del fitxer de configuració local/config/database.inc.php ha fallat.';
$lang['Download the config file'] = 'Descarregat l\'arxiu de configuració';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Pots descarregar l\'arxiu de configuració i penjar-lo al directori local/config de la teva instal·lació.';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'No dubtis en consultar als nostres fòrums per a qualsevol ajuda: %s';
$lang['Just another Piwigo gallery'] = 'Just another Piwigo gallery';
$lang['Welcome to my photo gallery'] = 'Benvingut a la meva galeria fotogràfica';
$lang['Welcome to your new installation of Piwigo!'] = 'Benvingut a la teva nova instal·lació de Piwigo!';
$lang['localhost or other, supplied by your host provider'] = 'localhost o un altre, facilitat pel teu proveïdor d\'allotjament';
